% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/V_llogis.R
\name{V_llogis}
\alias{V_llogis}
\title{Variance of the Loglogistic distribution}
\usage{
V_llogis(shape, rate = 1/scale, scale = 1/rate)
}
\arguments{
\item{shape}{shape parameter \eqn{\tau}{tau}, must be positive integer.}

\item{rate}{alternative parameterization the scale parameter, rate = 1 / scale.}

\item{scale}{\eqn{\lambda}{lambda} rate parameter, must be positive.}
}
\value{
Function :
 \itemize{
 \item{\code{\link{E_llogis}}}{ gives the expected value.}
 \item{\code{\link{V_llogis}}}{ gives the variance.}
 \item{\code{\link{kthmoment_llogis}}}{ gives the kth moment.}
 \item{\code{\link{Etronq_llogis}}}{ gives the truncated mean.}
 \item{\code{\link{SL_llogis}}}{ gives the stop-loss.}
 \item{\code{\link{Elim_llogis}}}{ gives the limited mean.}
 \item{\code{\link{Mexcess_llogis}}}{ gives the mean excess loss.}
 \item{\code{\link{TVaR_llogis}}}{ gives the Tail Value-at-Risk.}
 \item{\code{\link{VaR_llogis}}}{ gives the Value-at-Risk.}
 }
 Invalid parameter values will return an error detailing which parameter is problematic.
}
\description{
Variance of the Loglogistic distribution with shape parameter
 \eqn{\tau}{tau} and scale parameter \eqn{\lambda}{lambda}.
}
\details{
The Loglogistic distribution with shape parameter \eqn{\tau}{t} and scale parameter
  \eqn{\lambda}{lam} has density:
  \deqn{\frac{\tau \lambda^\tau x^{\tau -1}}{(\lambda^{\tau }+x^{\tau })^{2}}}{f(x) = t lam^t x^(t - 1) / (lam^t + x^t)^2}
  for \eqn{x \in \mathcal{R}^+}{x > 0}, \eqn{\lambda, \tau > 0}{lam, t > 0}.
}
\examples{

# With scale parameter
V_llogis(shape = 3, scale = 5)

# With rate parameter
V_llogis(shape = 3, rate = 0.2)

# Equivalently :
kthmoment_llogis(k = 2, shape = 3, rate = 0.2) - kthmoment_llogis(k = 1, shape = 3, rate = 0.2)^2

}
\seealso{
Other Loglogistic Distribution: 
\code{\link{E_llogis}()},
\code{\link{Elim_llogis}()},
\code{\link{Etronq_llogis}()},
\code{\link{Mexcess_llogis}()},
\code{\link{SL_llogis}()},
\code{\link{TVaR_llogis}()},
\code{\link{VaR_llogis}()},
\code{\link{kthmoment_llogis}()}
}
\concept{Loglogistic Distribution}
